#
# SVN.py - Subversion interface
#
# Copyright (c) 2006 The DITrack Project, www.ditrack.org.
#
# $Id: SVN.py 419 2006-08-21 02:08:48Z vss $
# $HeadURL: file:///X/svn/ditrack/src/tags/0.4/DITrack/SVN.py $
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions are met:
#
#  * Redistributions of source code must retain the above copyright notice, 
# this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above copyright notice, 
# this list of conditions and the following disclaimer in the documentation 
# and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.
#

import os
import popen2

svn = "svn"

def propget(propname, path):
	p = popen2.Popen3((svn, "propget", propname, path))

	str = ""

	while 1:
		s = p.fromchild.readline()
		if not s: break

		str = str + s

	ec = p.wait()

	if os.WIFEXITED(ec) and (os.WEXITSTATUS(ec) == 0):
		return str.rstrip("\n")

	return None

def svn_add(globals, fname):
	args = [ globals.svn_path, "add", "-Nq", fname ]
	return os.spawnvp(os.P_WAIT, globals.svn_path, args)

def svn_commit(globals, logmsg, fnames):
	if len(fnames) == 0:
		return 0

	args = [ globals.svn_path, "commit", "-q", "-m", logmsg ] + fnames
	return os.spawnvp(os.P_WAIT, globals.svn_path, args)

# Operation types
OP_ADD = 0	# Add file
OP_CHANGE = 1	# Mark file as modified
OP__QTY = 2

class Operation:
	"A basic operation"
	def __init__(self, type, fname):
		assert(type >= 0)
		assert(type < OP__QTY)

		self.type = type
		self.fname = fname

class Transaction:
	"Single transaction: a bunch of operations"
	def __init__(self, globals, ops):
		self.globals = globals
		self.ops = ops

	def commit(self, logmsg):
		commit_list = {}

		for o in self.ops:
			if o.type == OP_ADD:
				rc = svn_add(self.globals, o.fname)
				# XXX: raise exception here?
				if rc:
					return rc

				commit_list[o.fname] = 1

			elif o.type == OP_CHANGE:
				commit_list[o.fname] = 1
			else:
				raise NotImplementedError

		rc = svn_commit(self.globals, logmsg, commit_list.keys())

		return rc
